@@ -38,12 +38,12 @@ Box_DB_Table::~Box_DB_Table()
 
 Glib::ustring Box_DB_Table::get_table_name()
 {
-  return m_strTableName;
+  return m_table_name;
 }
 
-bool Box_DB_Table::init_db_details(const Glib::ustring& strTableName)
+bool Box_DB_Table::init_db_details(const Glib::ustring& table_name)
 {
-  m_strTableName = strTableName;
+  m_table_name = table_name;
 
   if(!ConnectionPool::get_instance()->get_ready_to_connect())
     return false;
@@ -59,41 +59,24 @@ bool Box_DB_Table::refresh_data_from_database()
   return fill_from_database();
 }
 
-Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const LayoutItem_Field& /* field */) const
+Gnome::Gda::Value Box_DB_Table::get_entered_field_data_field_only(const sharedptr<const Field>& field) const
+{
+  sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+  layout_item->set_full_field_details(field); 
+
+  return get_entered_field_data(layout_item);
+}
+
+Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const sharedptr<const LayoutItem_Field>& /* field */) const
 {
   //Override this to use Field::set_data() too.
 
   return Gnome::Gda::Value(); //null
 }
 
-void Box_DB_Table::set_entered_field_data(const LayoutItem_Field& /* field */, const Gnome::Gda::Value& /* value */)
-{
-  //Override this.
-}
-
-bool Box_DB_Table::get_field_primary_key_for_table(const Glib::ustring& table_name, Field& field) const
-{
-  const Document_Glom* document = get_document();
-  if(document)
-  {
-    //TODO_Performance:
-    Document_Glom::type_vecFields fields = document->get_table_fields(table_name);
-    for(Document_Glom::type_vecFields::iterator iter = fields.begin(); iter != fields.end(); ++iter)
-    {
-      if(iter->get_primary_key())
-      {
-        field = *iter;
-        return true;
-      }
-    }
-  }
-
-  return false;
-}
-
 unsigned long Box_DB_Table::get_last_auto_increment_value(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model, const Glib::ustring& /* field_name */)
 {
-  sharedptr<SharedConnection> sharedconnection = connect_to_server();
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
   if(sharedconnection)
   {
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
@@ -111,25 +94,8 @@ unsigned long Box_DB_Table::get_last_auto_increment_value(const Glib::RefPtr<Gno
     return 0;
 }
 
-bool Box_DB_Table::get_fields_for_table_one_field(const Glib::ustring& table_name, const Glib::ustring& field_name, Field& field) const
-{
-  //Initialize output parameter:
-  Field result = Field();
-
-  type_vecFields fields = get_fields_for_table(table_name);
-  type_vecFields::iterator iter = std::find_if(fields.begin(), fields.end(), predicate_FieldHasName<Field>(field_name));
-  if(iter != fields.end()) //TODO: Handle error?
-  {
-    field = *iter;
-    return true;
-  }
-
-  return false;
-}
-
-
-
 //static:
+/*
 Box_DB_Table::type_vecFields Box_DB_Table::get_fields_for_datamodel(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model)
 {
   type_vecFields result;
@@ -138,13 +104,14 @@ Box_DB_Table::type_vecFields Box_DB_Table::get_fields_for_datamodel(const Glib::
   for(int i = 0; i < columns; ++i)
   {
     Gnome::Gda::FieldAttributes fieldinfo = data_model->describe_column(i);
-    Field field;
-    field.set_field_info(fieldinfo); //TODO: Get glom-specific information from document?
+    sharedptr<Field> field(new Field());
+    field->set_field_info(fieldinfo); //TODO: Get glom-specific information from document?
     result.push_back( field );
   }
 
   return result;
 }
+*/
 
 Glib::ustring Box_DB_Table::postgres_get_field_definition_for_sql(const Gnome::Gda::FieldAttributes& field_info)
 {
