@@ -23,7 +23,7 @@
 #include "appstate.h"
 #include "mode_design/users/dialog_groups_list.h"
 #include "dialog_database_preferences.h"
-#include "dialog_layout_report.h"
+#include "reports/dialog_layout_report.h"
 #include "utils.h"
 #include "data_structure/glomconversions.h"
 #include "data_structure/layout/report_parts/layoutitem_summary.h"
@@ -411,7 +411,21 @@ void Frame_Glom::show_table(const Glib::ustring& table_name)
       case(MODE_Data):
       {
         strMode = _("Data");
-        m_Notebook_Data.init_db_details(m_table_name);
+        FoundSet found_set;
+        found_set.m_table_name = m_table_name;
+
+        //Sort by the ID, just so we sort by something, so that the order is predictable:
+        sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
+        if(field_primary_key)
+        {
+          sharedptr<LayoutItem_Field> layout_item_sort = sharedptr<LayoutItem_Field>::create();
+          layout_item_sort->set_full_field_details(field_primary_key);
+
+          found_set.m_sort_clause.clear();
+          found_set.m_sort_clause.push_back( type_pair_sort_field(layout_item_sort, true /* ascending */) );
+        }
+
+        m_Notebook_Data.init_db_details(found_set);
         set_mode_widget(m_Notebook_Data);
 
         //Show how many records were found:
@@ -458,9 +472,16 @@ void Frame_Glom::on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction
       bool test = get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER);
       if(test)
       {
+        std::cout << "DEBUG: User=" << connection_pool->get_user() << " _is_ in the developer group on the server." << std::endl;
         //Avoid double signals:
         //if(document->get_userlevel() != AppState::USERLEVEL_DEVELOPER)
         test = document->set_userlevel(AppState::USERLEVEL_DEVELOPER);
+        if(!test)
+          std::cout << "  DEBUG: But document->set_userlevel(AppState::USERLEVEL_DEVELOPER) failed." << std::endl;
+      }
+      else
+      {
+        std::cout << "DEBUG: User=" << connection_pool->get_user() << " is _not_ in the developer group on the server." << std::endl;
       }
 
       //If this was not possible then revert the menu:
@@ -529,7 +550,7 @@ void Frame_Glom::on_menu_file_export()
 
   //const int index_primary_key = fieldsSequence.size() - 1;
 
-  const Glib::ustring found_set_where_clause = m_Notebook_Data.get_where_clause();
+  const FoundSet found_set = m_Notebook_Data.get_found_set();
 
   std::fstream the_stream(filepath.c_str(), std::ios_base::out | std::ios_base::trunc);
   if(!the_stream)
@@ -538,20 +559,20 @@ void Frame_Glom::on_menu_file_export()
     return;
   }
 
-  export_data_to_stream(the_stream, m_table_name, mapGroupSequence, found_set_where_clause);
+  export_data_to_stream(the_stream, found_set, mapGroupSequence);
 }
 
-void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const Glib::ustring table_name, const Document_Glom::type_mapLayoutGroupSequence& sequence, const Glib::ustring& where_clause)
+void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence)
 {
-  type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(table_name, sequence);
+  type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
 
   if(fieldsSequence.empty())
     return;
 
-  const Glib::ustring query = GlomUtils::build_sql_select_with_where_clause(table_name, fieldsSequence, where_clause);
+  const Glib::ustring query = GlomUtils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_sort_clause);
 
   //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query);
+  Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query, get_app_window());
 
   guint rows_count = 0;
   if(result)
@@ -590,17 +611,17 @@ void Frame_Glom::export_data_to_string(Glib::ustring& the_string, const Glib::us
   }
 }
 
-void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const Glib::ustring table_name, const Document_Glom::type_mapLayoutGroupSequence& sequence, const Glib::ustring& where_clause)
+void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence)
 {
-  type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(table_name, sequence);
+  type_vecLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
 
   if(fieldsSequence.empty())
     return;
 
-  const Glib::ustring query = GlomUtils::build_sql_select_with_where_clause(table_name, fieldsSequence, where_clause);
+  const Glib::ustring query = GlomUtils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_sort_clause);
 
   //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query);
+  Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query, get_app_window());
 
   guint rows_count = 0;
   if(result)
@@ -812,7 +833,10 @@ void Frame_Glom::on_notebook_find_criteria(const Glib::ustring& where_clause)
     pApp->set_mode_data();
 
     //std::cout << "Frame_Glom::on_notebook_find_criteria: where_clause=" << where_clause << std::endl;
-    const bool records_found = m_Notebook_Data.init_db_details(m_table_name, where_clause);
+    FoundSet found_set;
+    found_set.m_table_name = m_table_name;
+    found_set.m_where_clause = where_clause;
+    const bool records_found = m_Notebook_Data.init_db_details(found_set);
 
     //std::cout << "Frame_Glom::on_notebook_find_criteria(): BEFORE  m_Notebook_Data.select_page_for_find_results()" << std::endl;
     m_Notebook_Data.select_page_for_find_results();
@@ -1220,7 +1244,16 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
           std::cout << "Frame_Glom::connection_request_password_and_choose_new_database_name(): unused database name successfully found: " << database_name_possible << std::endl; 
           //The connection to the server is OK, but the specified database does not exist.
           //That's good - we were looking for an unused database name.
-          get_document()->set_connection_database(database_name_possible);
+          Document_Glom* document = get_document();
+          if(document)
+          {
+            document->set_connection_database(database_name_possible);
+
+            ConnectionPool* connection_pool = ConnectionPool::get_instance();
+            if(connection_pool)
+              document->set_connection_server(connection_pool->get_host());
+          }
+
           return true;
         }
       }
@@ -1328,14 +1361,38 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
       return false;
     }
 
+
     if(sharedconnection)
     {
-      Bakery::BusyCursor(*get_app_window());
+      Gtk::Window* pWindowApp = get_app_window();
+      g_assert(pWindowApp);
+
+      Bakery::BusyCursor busycursor(*pWindowApp);
 
       Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
       if(connection)
       {
-        connection->create_database(database_name);
+        const bool test = connection->create_database(database_name);
+        if(!test)
+        {
+          //Tell the user:
+          Gtk::Dialog* dialog = 0;
+          try
+          {
+            Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_error_create_database");
+            refXml->get_widget("dialog_error_create_database", dialog);
+            dialog->set_transient_for(*pWindowApp);
+            dialog->run();
+            delete dialog;
+          }
+          catch(const Gnome::Glade::XmlError& ex)
+          {
+            std::cerr << ex.what() << std::endl;
+          }
+
+           return false;
+        }
+
         //if(result)
         //{
         //  std::cout << "Frame_Glom::create_database(): Creation succeeded: database_name=" << database_name << std::endl;
@@ -1344,6 +1401,9 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
     }
   }
 
+  std::cout << "Frame_Glom::create_database(): debug 5" << std::endl;
+
+
   //Connect to the actual database:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   connection_pool->set_database(database_name);
@@ -1361,11 +1421,15 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
 
   if(sharedconnection)
   {
-    add_standard_tables(); //Add internal, hidden, tables.
+    bool test = add_standard_tables(); //Add internal, hidden, tables.
+    if(!test)
+      return false;
 
     //Create the developer group, and make this user a member of it:
     //If we got this far then the user must really have developer privileges already:
-    add_standard_groups();
+    test = add_standard_groups();
+    if(!test)
+      return false;
 
     //std::cout << "Frame_Glom::create_database(): Creation of standard tables and groups finished." << std::endl;
 
@@ -1407,7 +1471,8 @@ void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
   if(!report)
     return;
 
-  report_build(m_table_name, report, ""); //TODO: Use found set's where_claus.
+  FoundSet found_set = m_Notebook_Data.get_found_set();
+  report_build(found_set, report, get_app_window()); //TODO: Use found set's where_clause.
 }
 
 void Frame_Glom::on_dialog_layout_report_hide()
